/*
Code by @Dimzcraft.
(c) Don't use any Code without permission
*/
import { world, system } from "@minecraft/server";
import entityIdList from './entity_id';

function NearbyMobs(player) {
  const dimension = player.dimension;
  if (!dimension) return;

  const entityDetection = dimension.getEntities({
    location: player.location,
    maxDistance: 20,
    excludeTypes: [
      "minecraft:item",
      "minecraft:xp_orb",
      "minecraft:armor_stand",
      "minecraft:leash_knot"
    ]
  });

  const rotation = player.getRotation();
  const yaw = rotation.y * (Math.PI / 180);
  const forward = {
    x: -Math.sin(yaw),
    z: Math.cos(yaw)
  };

  const entityDetected = entityDetection
    .filter(entity => entity.nameTag !== player.nameTag)
    .filter(entity => {
      const vel = entity.getVelocity();
      return vel.x !== 0 || vel.y !== 0 || vel.z !== 0;
    })
    .map(entity => {
      const dirToEntity = {
        x: entity.location.x - player.location.x,
        z: entity.location.z - player.location.z
      };

      const dot = forward.x * dirToEntity.x + forward.z * dirToEntity.z;
      const cross = forward.x * dirToEntity.z - forward.z * dirToEntity.x;

      const label = entity.nameTag || entityIdList[entity.typeId] || entity.typeId;

      if (dot > 0) {
        if (cross > 2) return `  ${label}§r§f >`;
        else if (cross < -2) return `< ${label}§r§f  `;
        else return `${label}§r§f`;
      } else {
        return `< ${label}§r§f >`;
      }
    })
    .slice(0, 10)
    .join("\n");

  player.onScreenDisplay.setTitle(`§d§m§z§n§m§s§r§f${entityDetected}`);
};


system.runInterval(() => {
  for (const player of world.getPlayers()) {
    NearbyMobs(player);
  }
}, 10);